@@ -515,14 +515,7 @@ class Galaxy:
         self.file_name = file_name
         self.access_token = access_token
 
-    def fetch(
-        self,
-        output_format,
-        is_hdx_export=False,
-        all_feature_filter_json=None,
-        min_zoom=None,
-        max_zoom=None,
-    ):
+    def fetch(self, output_format, is_hdx_export=False, all_feature_filter_json=None):
         if all_feature_filter_json:
             with open(all_feature_filter_json, encoding="utf-8") as all_features:
                 all_features_filters = json.loads(all_features.read())
@@ -694,7 +687,7 @@ class Galaxy:
                                         res = r.json()
                                         if res["status"] == "FAILURE":
                                             raise ValueError(
-                                                "Task failed from Raw Data api"
+                                                "Task failed from raw data api"
                                             )
                                         if res["status"] == "SUCCESS":
                                             success = True
@@ -705,7 +698,7 @@ class Galaxy:
                                             time.sleep(
                                                 0.5
                                             )  # wait one half sec before making another request
-                                        else:
+                                        else : 
                                             time.sleep(2)  # Check every 2s for hdx
 
                         except requests.exceptions.RequestException as ex:
@@ -810,9 +803,7 @@ class Galaxy:
                 "geometry": geom,
                 "outputType": output_format,
             }
-        if output_format == "mbtiles":
-            request_body["minZoom"] = min_zoom
-            request_body["maxZoom"] = max_zoom
+
         headers = {"accept": "application/json", "Content-Type": "application/json"}
         if self.access_token:
             headers["access-token"] = self.access_token
@@ -850,12 +841,12 @@ class Galaxy:
                     if r.ok:
                         res = r.json()
                         if res["status"] == "FAILURE":
-                            raise ValueError("Task failed from export tool api")
+                            raise ValueError("Task failed from raw data api")
                         if res["status"] == "SUCCESS":
-                            success = True
-                            return [res["result"]]
-                        else:
-                            time.sleep(1)  # Check each 1 seconds
+                            if res['result'].get('download_url'):
+                                success = True
+                                return [res["result"]]
+                        time.sleep(1)  # Check each 1 seconds
 
         except requests.exceptions.RequestException as ex:
             raise ex
